#
# spec file for package adios
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _lto_cflags %{?_lto_cflags} -ffat-lto-objects

%global mpi_flavor openmpi4%{nil}

%define pname adios

%if "%{mpi_flavor}" == ""
ExclusiveArch:  do_not_build
%global p_suffix %{nil}
%else
%global p_suffix -%{mpi_flavor}
%endif

# No netcdf on s390 and 32bit platforms
ExcludeArch:    s390 s390x i586 %arm

%if "%{mpi_flavor}" == "openmpi5"
ExcludeArch:    %{ix86} %{arm}
%endif

%define p_prefix %{_libdir}/mpi/gcc/%{mpi_flavor}

%define p_bindir %{p_prefix}/bin/
%define p_libdir %{p_prefix}/%{_lib}/
%define p_incdir %{p_prefix}/include/
%define p_datadir %{p_prefix}/share/
%define p_sysconfdir %{p_prefix}/etc/
%define p_skeldir %{p_prefix}/etc/skel/

%if 0%{?suse_version} >= 1500
%define my_py_version 3
%endif

Name:           adios%{?p_suffix}
Version:        1.13.1
Release:        8.1
Summary:        The Adaptable IO System (ADIOS)
License:        BSD-2-Clause AND BSD-3-Clause AND LGPL-2.1-or-later
Group:          Productivity/Scientific/Other
URL:            https://www.olcf.ornl.gov/center-projects/adios/
Source0:        https://users.nccs.gov/~pnorbert/adios-%{version}.tar.gz
Patch0:         adios-correct-func-ret.patch
Patch1:         Fix-code-to-be-python3-compliant.patch
BuildRequires:  %{mpi_flavor}-devel
BuildRequires:  autoconf
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  hdf5%{?p_suffix}-devel
BuildRequires:  libbz2-devel
BuildRequires:  liblz4-devel
BuildRequires:  netcdf%{?p_suffix}-devel
BuildRequires:  python%{?my_py_version}
BuildRequires:  zlib-devel
Requires:       python%{?my_py_version}-PyYAML
Requires:       python%{?my_py_version}-xml

%description
The Adaptable IO System (ADIOS) provides a way for scientists to
describe the data in their code that may need to be written, read, or
processed outside of the running simulation. By providing an external
to the code XML file describing the various elements, their types,
and how one wishes to process them for a particular run, the routines
in the host code (either FORTRAN or C) can transparently change how
they process the data.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/Parallel
Requires:       %{name} = %{version}
Requires:       %{name}-devel-static = %{version}
Requires:       hdf5%{?p_suffix}-devel
Requires:       netcdf%{?p_suffix}-devel

%description devel
The Adaptable IO System (ADIOS) provides a way for scientists to
describe the data in their code that may need to be written, read, or
processed outside of the running simulation.

This package contains all files needed to create projects that use
the %{flavor} version of ADIOS.

%package devel-static
Summary:        Static libraries for %{name}
Group:          Development/Libraries/Parallel

%description devel-static
The Adaptable IO System (ADIOS) provides a way for scientists to
describe the data in their code that may need to be written, read, or
processed outside of the running simulation.

This package contains all the static libraries needed to create projects
that use the %{flavor} version of ADIOS.

%prep
%autosetup -p1 -n %{pname}-%{version}

%build

export CC=gcc
export CXX=g++
export F77=gfortran
export F9X=gfortran
export FC=gfortran
export MPICC=mpicc
export MPICXX=mpicxx
export MPIFC=mpif90
export CFLAGS="-fPIC %{optflags}"
%if 0%{?suse_version} >= 1550
# https://github.com/ornladios/ADIOS/issues/206
export FCFLAGS="-fPIC %{optflags} -fallow-argument-mismatch"
%else
export FCFLAGS="-fPIC %{optflags}"
%endif
export LDFLAGS="-pie"

export MPICC="%{p_bindir}/mpicc"
export MPIFC="%{p_bindir}/mpif90"
export PATH=${PATH}:%{p_bindir}
export LDFLAGS="${LDFLAGS} -L%{p_libdir}"
export LD_LIBRARY_PATH="%{p_libdir}"
%configure \
  --prefix=%{p_prefix} \
  --exec-prefix=%{_prefix} \
  --bindir=%{p_bindir} \
  --libdir=%{p_libdir} \
  --includedir=%{p_incdir} \
  --sysconfdir=%{p_sysconfdir} \
  --datadir=%{p_datadir} \
  --docdir=%{_docdir}/%{name} \
  --enable-fortran \
  --with-phdf5="%{p_prefix}" \
  --with-netcdf="%{p_prefix}" \
  --with-zlib="%{_prefix}" \
  --with-bzip2="%{_libdir}" \
  --with-lz4="%{_libdir}" \
  --without-evpath \
  --without-fastbit \
  --without-ffs \

make V=1 %{?_smp_mflags}

%install
%make_install
for i in %{buildroot}/%{p_bindir}/{skel,*.py} %{buildroot}/%{p_libdir}/python/*.py; do
    sed -e '1s@^\(#!.*\)\(python\)[23]*\( *.*\)@\1\2%{?my_py_version}\3@' -e '1s@/\env @/@' -i $i
done
%fdupes -s %{buildroot}/%{p_skeldir}/templates

%files
%{p_bindir}
%config %{p_sysconfdir}/*
%dir %{p_prefix}/etc
%{p_skeldir}
%{p_libdir}/python
%license COPYING
%doc AUTHORS KNOWN_BUGS NEWS README.md TODO

%files devel
%{p_incdir}

%files devel-static
%{p_libdir}/*.a

%changelog
* Tue Mar 25 2025 Nicolas Morey <nicolas.morey@suse.com>
- Remove gnu-hpc build flavours (bsc#1239982)
- Add openmpi5 build flavour
- openmpi5 is not available on 32b systems
- Fix mpi_ver for openmpi5
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Mon Oct 23 2023 Nicolas Morey <nicolas.morey@suse.com>
- Drop support for obsolete openmpi[123]
- Prepare support for openmpi5
* Fri Feb  5 2021 Egbert Eich <eich@suse.com>
- Add build support for gcc10 to HPC build (bsc#1174439).
- Add openmpi4 flavors.
- Add Fix-code-to-be-python3-compliant.patch:
  * Remove python2 code and dependencies.
  * Removed & Automated: fix_python_shebang.patch
  * Make python3 the default for TW and SLE/Leap 15
- Do not mark template files for HPC as %%config.
* Wed Feb  3 2021 Egbert Eich <eich@suse.com>
- Change 'Requires:' to other HPC packages to %%requires_eq to depend
  on the exact version. This should take care of HPC packages ignoring
  proper ABI versioning.
* Mon Jul 20 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Adapt to HPC module netcdf naming change (boo#1174291).
* Sat Jul 18 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Drop numpy build dependency. The numpy wrapper is currently not
  built, and can be built separately.
- Add -fallow-argument-mismatch Fortran flag to workaround
  GFortran10 being more strict by default.
* Sat Nov 30 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Correct naming of openmpi1 packages in Leap 15.0/15.1 (still
  called openmpi), fixes unresolvable packages.
- Add non-HPC openmpi2 and openmpi3 flavors.
* Fri Nov 29 2019 Egbert Eich <eich@suse.com>
- Add support for gcc7.
- Add support for gcc8 and gcc9 (jsc#SLE-7766 & jsc#SLE-8604).
* Fri Nov 29 2019 Egbert Eich <eich@suse.com>
- Disable openmpi1 builds for SLE/Leap > 15.1.
- Enable openmpi3 builds for Leap and SLE > 15.1 (jsc#SLE-7773).
- Disable build on s390/s390x as netcdf is not available (bsc#1157965).
- Fix openmpi1 names for non-HPC builds on Factory.
* Fri Nov 29 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Add missing FCFLAGS export
* Thu Nov 28 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix aarch64 LTO build with -ffat-lto-objects flag
* Fri Oct 18 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Disable openmpi3 and the openmpi flavor in SLE.
* Mon Oct  7 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Remake patch adios-correct-func-ret.patch to make sure the functions
  return something instead of changing the return type from int to void.
* Mon Apr 29 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Move the static libraries to a -devel-static packages. Adios doesn't
  provides shared libraries and the static libraries are required for
  the bindings to work.
* Wed Apr 10 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Fix path for the files that were installed directly at /etc.
* Mon Apr  8 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Update Licensing.
* Fri Mar 29 2019 Jan Engelhardt <jengelh@inai.de>
- Generalize and trim bias from description.
* Thu Mar 28 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Drop the packages and flavors for examples/examples-hpc. It's easier
  for an interested user to download directly the source package and build
  them directly.
- Update the URLs to use https
- Add -L option to the standard master package
- Delete the module .version file in the %%postun if it's the default one
- Use the macro %%hpc_modules_init to load the module files
* Mon Mar 25 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Re-add CPATH, C_INCLUDE_PATH and CPLUS_INCLUDE_PATH to the module
  file.
- Add a separate package with the examples in two flavors one for
  non-HPC and another one for HPC: examples and examples-hpc.
- Update Requires for the devel package.
* Wed Feb 20 2019 Ana Guerrero López <aguerrero@suse.com>
- Update to version 1.31.1 (jsc#SLE-6004)
- Add python support:
  * This is only for Python2
  * Update in the module file
  * Add needed Requires on python2-xml and python2-PyYAML
- Fix a few python shebangs with patch fix_python_shebang.patch
- Add a Requires on hdf5 for every mpi flavor and update the module
  file with 'depends-on phdf5'.
- Add examples packages. It's only created for the openmpi flavor
  to avoid having several packages with the same content.
- Spec file polishing: spec-cleaner and update to the lastest
  packaging convention for HPC packages.
* Tue Jan  9 2018 jjolly@suse.com
- Added hpc macros support
  * Added _multibuild with serial, openmpi, and gnu-openmpi-hpc
  * Created devel package and module package
  * Created lua lmod module file for adios
- Added adios-correct-func-ret.patch
* Fri Jan  5 2018 jjolly@suse.com
- First pass on adios specfile
